##
##  arpalert.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2008 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         arpalert
Summary:      ARP Network Monitoring & Alerting
URL:          http://www.arpalert.org/
Vendor:       Thierry FOURNIER
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Mapping
License:      GPL
Version:      2.0.11
Release:      20080401

#   list of sources
Source0:      http://www.arpalert.org/src/arpalert-%{version}.tar.gz
Source1:      arpalert.conf
Source2:      rc.arpalert
Patch0:       arpalert.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20060823, gcc, make
PreReq:       OpenPKG, openpkg >= 20060823
BuildPreReq:  libpcap
PreReq:       libpcap
AutoReq:      no
AutoReqProv:  no

%description
    ARPAlert listens on a network interface (without using 'promiscuous'
    mode) and catches all requests for MAC address to IP conversion. It
    then compares the MAC addresses it detected with a pre-configured
    list of authorized MAC addresses. If the MAC is not in list,
    ARPAlert launches a pre-defined user script with the MAC address and
    IP address as parameters.

%track
    prog arpalert = {
        version   = %{version}
        url       = http://www.arpalert.org/index.php?page=download
        regex     = arpalert-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0
    %{l_shtool} subst \
        -e 's;\(@localstatedir@/\)lib/arpalert;\1db;' \
        Makefile.in \
        install.sh.in

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --localstatedir=%{l_prefix}/var/arpalert
    %{l_make} %{l_mflags -O}

%install
    rm -rf $RPM_BUILD_ROOT
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    strip $RPM_BUILD_ROOT%{l_prefix}/sbin/* >/dev/null 2>&1 || true
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE arpalert.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/arpalert/
    %{l_shtool} install -c -m 644 \
        /dev/null $RPM_BUILD_ROOT%{l_prefix}/etc/arpalert/arpalert.authreq
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.arpalert} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/arpalert/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/arpalert/*'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} arpalert status 2>/dev/null`
    [ ".$arpalert_active" = .yes ] && %{l_rc} arpalert restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} arpalert stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/arpalert/run/* >/dev/null 2>&1 || true
    rm -f $RPM_INSTALL_PREFIX/var/arpalert/log/* >/dev/null 2>&1 || true
    exit 0

